@@ -22,20 +22,19 @@ else:
 
 
 class Config:
-  def __init__(self,nodeHighlightBehavior=True, highlightColor="#F7A7A6",directed=True):
+  def __init__(self, height=800, width=1000, nodeHighlightBehavior=True, highlightColor="#F7A7A6", directed=True, collapsible=True):
+    self.height = height
+    self.width = width
     self.nodeHighlightBehavior = nodeHighlightBehavior
-    self.highlightColor = "black"
-    self.height = 800
-    self.width = 1000
+    self.highlightColor = highlightColor
     self.automaticRearrangeAfterDropNode=True
-    self.collapsible=True
+    self.collapsible=collapsible
     self.directed=directed
-    self.node = { "highlightStrokeColor":"#F7A7A6"} #"highlightColor":"black",
-    self.link = {"highlightColor": "#FDD2BS"}
+    # self.node = { "highlightStrokeColor":"#F7A7A6"} #"highlightColor":"black",
+    # self.link = {"highlightColor": "#FDD2BS"}
 
-  def to_json(self):
-    return json.dumps(self, default=lambda o: o.__dict__,
-            sort_keys=True, indent=4)
+  def to_dict(self):
+    return self.__dict__
 
 class Node:
   def __init__(self,
@@ -90,17 +89,21 @@ class Edge:
 # def parse_node(*args):
 #  nodes_data = [{"id": f"{node}"} for node in nodes]
 
-def agraph(nodes, edges):
+def agraph(nodes, edges, config):
 
     nodes_data = [ node.to_dict() for node in nodes]
     edges_data = [ edge.to_dict() for edge in edges]
 
     #nodes_data = [{"id": f"{node}"} for node in nodes]
     #edges_data = [ {"source": f"{edge[0]}", "target": f"{edge[1]}"} for edge in edges]
-    config = Config().to_json()
+
+    config_json = json.dumps(config.__dict__)
+    # st.write(config_json)
+
     data = { "nodes": nodes_data, "links": edges_data}
+    # st.write(data)
     data_json = json.dumps(data)
-    component_value = _agraph(data=data_json,config=config)
+    component_value = _agraph(data=data_json, config=config_json)
 
     return component_value
 
@@ -110,21 +113,22 @@ if not _RELEASE:
     import streamlit as st
 
     st.subheader("Component with constant args")
-    # nodes.append( Node(id="Chris_Klose", size=400, svg="https://github.com/ChrisChross/streamlit-agraph/blob/master/imgs/Chris.png?raw=true") ) #
-    # edges.append(Edge(source="Chris_Klose", target="Spiderman", type="CURVE_SMOOTH"))
     nodes = []
     edges = []
     nodes.append( Node(id="Spiderman", size=400, svg="http://marvel-force-chart.surge.sh/marvel_force_chart_img/top_spiderman.png") ) # ,
     nodes.append( Node(id="Captain_Marvel", size=400, svg="http://marvel-force-chart.surge.sh/marvel_force_chart_img/top_captainmarvel.png"))
-    edges.append( Edge(source="Chris_Klose", target="Spiderman", type="CURVE_SMOOTH") )
     edges.append(Edge(source="Captain_Marvel", target="Spiderman", type="CURVE_SMOOTH"))
+    # nodes.append( Node(id="Chris_Klose", size=400, svg="https://github.com/ChrisChross/streamlit-agraph/blob/master/imgs/Chris.png?raw=true") ) #
+    # edges.append(Edge(source="Chris_Klose", target="Spiderman", type="CURVE_SMOOTH"))
+    # edges.append( Edge(source="Chris_Klose", target="Spiderman", type="CURVE_SMOOTH") )
    # edges.append(Edge(source="Chris_Klose", target="Captain_Marvel", type="CURVE_SMOOTH" )) # renderLabel=True, labelProperty="best_friend_of"
     #nodes = ["Harry","Sally","Peter","Chris"]
     #edges = [("Harry","Sally"),("Peter","Chris")]
 
     # myConfig = { "nodeHighlightBehavior": "true", "node": { "color": "lightgreen", "size": 120, "highlightStrokeColor": "blue",}, "link": { "highlightColor": "lightblue",}, }
 
-    return_value = agraph(nodes=nodes, edges=edges)
+    config = Config(width=500, height=500, directed=True)
+    return_value = agraph(nodes=nodes, edges=edges, config=config)
 
     # st.write(return_value)
     # st.markdown("You've clicked %s times!" % int(num_clicks))
